@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -45,7 +45,7 @@ Q_GLOBAL_STATIC(KAddressBookPluginInterfacePrivate, sInstance)
 
 KAddressBookPluginInterface::KAddressBookPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent),
-      mMainWidget(Q_NULLPTR)
+      mMainWidget(nullptr)
 {
     setPluginName(QStringLiteral("kaddressbook"));
     setServiceTypeName(QStringLiteral("KAddressBook/MainViewPlugin"));
